@@ -1,5 +1,6 @@
-name = 'pycromanager'
+name = "pycromanager"
 
 from pycromanager.acquire import Acquisition, multi_d_acquisition_events
 from pycromanager.core import Bridge, JavaObjectShadow
 from pycromanager.data import Dataset
+from ._version import __version__, version_info
